@@ -47,6 +47,11 @@ namespace Ui
 class MainWindow;
 }
 
+namespace Status
+{
+enum { NotInstalled, Installed, Upgradable };
+}
+
 namespace Tab
 {
 enum { Popular, EnabledRepos, Test, Backports, Flatpak, Output };
@@ -69,7 +74,7 @@ enum {
 } // namespace PopCol
 namespace TreeCol
 {
-enum { Check, Name, Version, Description, Status, Displayed };
+enum { Check, Name, Version, Description, Status };
 }
 namespace FlatCol
 {
@@ -263,9 +268,11 @@ private:
     QNetworkAccessManager manager;
     QNetworkReply *reply;
 
-    bool isOnline();
+    QString mapArchToFormat(const QString &arch);
     bool downloadAndUnzip(const QString &url, QFile &file);
     bool downloadAndUnzip(const QString &url, const QString &repo_name, const QString &branch, const QString &format,
                           QFile &file);
     bool downloadFile(const QString &url, QFile &file);
+    bool isOnline();
+    bool isPackageInstallable(const QString &installable, const QString &modArch);
 };
